---
title: <span class="badge builder"></span> ExprTypeClassicConditionsConditionsReducer
---
# <span class="badge builder"></span> ExprTypeClassicConditionsConditionsReducer

## Constructor

```python
ExprTypeClassicConditionsConditionsReducer()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> expr.ExprTypeClassicConditionsConditionsReducer
```

### <span class="badge object-method"></span> type_val

```python
def type_val(type_val: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ExprTypeClassicConditionsConditionsReducer](./object-ExprTypeClassicConditionsConditionsReducer.md)
